@@ -4,11 +4,9 @@ import 'package:{{ package_name }}/core/architecture/mobx_viewmodel.dart';
 
 part '{{ name_lower }}_viewmodel.g.dart';
 
-class {{ name }}Args {}
-
 class {{ name }}ViewModel = _{{ name }}ViewModel with _${{ name }}ViewModel;
 
-abstract class _{{ name }}ViewModel extends MobXViewModelWithArgs<AppRepository, AppRouter, {{ name }}Args> with Store {
+abstract class _{{ name }}ViewModel extends MobXViewModel<AppRepository, AppRouter> with Store {
   /* Variable */
   /* State */
   /* Computed */
